@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.9_07';
+$VERSION = '0.9_08';
 
 package XML::Atom::Syndication::Namespace;
 use strict;
@@ -32,15 +32,14 @@ __END__
 
 =head1 NAME
 
-XML::Atom::Syndication - A SAX-based library for working
-with Atom Syndication Format (RFC 4287) feeds.
+XML::Atom::Syndication - portable Atom Syndication Format (RFC 4287) feeds processing.
 
 =head1 DESCRIPTION
 
 This project is the result of scratching ones own itch. I
 was writing some web software needed a full-featured library
 for working with Atom feeds that was easy to distribute and
-install on wide range of envrionments. Many of my software's
+install on wide range of environments. Many of my software's
 target audience are relative novices working with low-cost
 shared hosting environments. (A significant number don't
 even have shell access!) Creating a library that was easy to
@@ -49,7 +48,7 @@ other options failed to meet.
 
 Originally the module began as a very spartan XPath driven
 interface. At the time the format had just been introduced
-and was still vague and very extremely volitle. It was a
+and was still vague and very extremely volatile. It was a
 pretty wretched piece of software, but it got me through
 while the Atom Working Group worked out the details of the
 Atom Syndication Format.
@@ -90,6 +89,31 @@ syndication format and not the publishing protocol. The
 publishing protocol is still being worked out and is not an
 official standard at this time.
 
+=head2 ENCODING
+
+Perl has a spotty history of supporting international
+character sets prior to version 5.8.1. All caveats and
+cautions apply when using this package with character sets
+other then ASCII with versions of Perl before that time.
+
+When used with Perl 5.8.1 and higher XML::Atom::Syndication
+will look for the encoding in the XML declaration and
+convert it to UTF-8 right before parsing. This simplifies
+further processing a great deal. Perl 5.8+ uses UTF-8
+internally and numerous other modules (such as
+L<XML::Writer>) will only work with UTF-8 encoded content.
+
+I found this also has the added benefit of making this
+package more portable. Perl's built-in encoding converters
+are more extensive then what typically ships with the
+standard parser. By converting to UTF-8 using Perl's system
+before parsing the potential for an encoding module
+dependency is eliminated. All XML parsers must support
+UTF-8.
+
+All output using L<XML::Atom::Syndication::Writer> will be
+in UTF-8 regardless of the original encoding before parsing.
+
 =head1 DEPENDENCIES
 
 =over
@@ -100,8 +124,6 @@ official standard at this time.
 
 =item L<Class:ErrorHandler>
 
-=item L<Encode>
-
 =item L<MIME::Base64>
 
 =back
@@ -112,8 +134,6 @@ L<XML::Atom>, L<XML::RAI>
 
 http://www.atomenabled.org/developers/syndication/atom-format-spec.php
 
-F<TODO>
-
 =head1 LICENSE
 
 The software is released under the Artistic License. The
